# Making a new release of Voici

The recommended way to make a release is to use [`jupyter_releaser`](https://jupyter-releaser.readthedocs.io/en/latest/get_started/making_release_from_repo.html).

This repository contains the two workflows located under https://github.com/voila-dashboards/voici/actions:

- Step 1: Prep Release
- Step 2: Publish Release
